@@ -282,9 +282,13 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
         trellis.par.set(list(strip.background = list(col = "white")))
     }
 
-    ## reset strip color on exit
+    ## set graphics
     current.strip <- trellis.par.get("strip.background")
-    on.exit(trellis.par.set("strip.background", current.strip))
+    current.font <- trellis.par.get("fontsize")
+    
+    ## reset graphic parameters
+    on.exit(trellis.par.set(strip.background = current.strip,
+                            fontsize = current.font))
 
     ## extra.args setup
     extra.args <- list(...)
@@ -298,6 +302,9 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
     extra.args$main <- if ("main" %in% names(extra.args))
         quickText(extra.args$main, auto.text) else quickText("", auto.text)
 
+    if ("fontsize" %in% names(extra.args))
+        trellis.par.set(fontsize = list(text = extra.args$fontsize))
+    
     if (statistic == "median" && missing(conf.int)) conf.int <- c(0.75, 0.95)
 
     ## sub heading stat info
@@ -502,8 +509,10 @@ timeVariation <- function(mydata, pollutant = "nox", local.tz = NULL,
     ## hour ############################################################################
 
     if (difference) {
+        
         data.hour <- errorDiff(mydata, vars = "hour", type = type, poll1 = poll1,
                                poll2 = poll2, B = B, conf.int = conf.int)
+        
     } else {
 
         data.hour <- ldply(conf.int, proc, mydata, vars = "hour", pollutant, type, B = B,
@@ -928,8 +937,9 @@ wd.smean.normal <- function(wd, B = B, statistic, conf.int) {
     c(Mean = Mean, Lower = Mean - diff.wd, Upper = Mean + diff.wd)
 }
 
-errorDiff <- function(mydata, vars = "day.hour", poll1, poll2, type, B = B, conf.int = conf.int)
-{
+errorDiff <- function(mydata, vars = "day.hour", poll1, poll2, type, B = B,
+                      conf.int = conf.int) {
+    
     ## bootstrap mean difference confidence intervals
     ## rearrange data
     mydata <- dcast(mydata, ... ~ variable)
